@@ -396,8 +396,9 @@ def file(path):
 @app.route("/api/queue/push/", methods=["POST"])
 @login_check
 def queue_push():
-    data = request.json
-    job_hash = queue.push(data)
+    data = request.json["data"]
+    action = request.json["action"]
+    job_hash = queue.push({"data": data}, action)
     return job_hash
 
 @app.route("/api/queue/status/", methods=["POST"])
@@ -409,17 +410,22 @@ def queue_status():
 
 def queue_thread(path_to_local_server):
     while True:
-        next_job = queue.pop()
-        if next_job is not None:
-            _, hash, input_data = next_job
-            queue.start_job(hash)
-            response = requests.post(path_to_local_server + "/api/predict/", json=input_data)
-            if response.status_code == 200:
-                queue.pass_job(hash, response.json())
+        try:
+            next_job = queue.pop()
+            if next_job is not None:
+                _, hash, input_data, task_type = next_job
+                queue.start_job(hash)
+                response = requests.post(
+                    path_to_local_server + "/api/" + task_type + "/", json=input_data)
+                if response.status_code == 200:
+                    queue.pass_job(hash, response.json())
+                else:
+                    queue.fail_job(hash, response.text)
             else:
-                queue.fail_job(hash, response.text)
-        else:
+                time.sleep(1)
+        except Exception as e:
             time.sleep(1)
+            pass
 
 def start_server(interface, server_name, server_port=None, auth=None, ssl=None):
     if server_port is None:
@@ -440,6 +446,8 @@ def start_server(interface, server_name, server_port=None, auth=None, ssl=None):
     log = logging.getLogger('werkzeug')
     log.setLevel(logging.ERROR)
     if app.interface.enable_queue:
+        if auth is not None or app.interface.encrypt:
+            raise ValueError("Cannot queue with encryption or authenitcation enabled.")
         queue.init()
         app.queue_thread = threading.Thread(target=queue_thread, args=(path_to_local_server,))
         app.queue_thread.start()
