@@ -11,12 +11,14 @@ import random
 import os
 
 current_dir = os.getcwd()
+os.environ["GRADIO_TEST_MODE"] = "1"
 
 LOCAL_HOST = "http://localhost:{}"
 GOLDEN_PATH = "test/golden/{}/{}.png"
 TOLERANCE = 0.1
 TIMEOUT = 10
 
+GAP_TO_SCREENSHOT = 1
 
 def wait_for_url(url):
     for i in range(TIMEOUT):
@@ -78,13 +80,13 @@ class TestDemo(unittest.TestCase):
         driver = self.start_test(target=diff_texts_thread)
         elem = WebDriverWait(driver, TIMEOUT).until(
             EC.presence_of_element_located((By.CSS_SELECTOR,
-                                            ".panel:nth-child(1) .component:nth-child(1) .input_text"))
+                                            ".panel:nth-child(1) .component:nth-child(1) .input_text textarea"))
         )
         elem.clear()
         elem.send_keys("Want to see a magic trick?")
         elem = WebDriverWait(driver, TIMEOUT).until(
             EC.presence_of_element_located((By.CSS_SELECTOR,
-                                            ".panel:nth-child(1) .component:nth-child(2) .input_text"))
+                                            ".panel:nth-child(1) .component:nth-child(2) .input_text textarea"))
         )
         elem.clear()
         elem.send_keys("Let's go see a magic trick!")
@@ -108,6 +110,7 @@ class TestDemo(unittest.TestCase):
             "diff_texts", "magic_trick"))
         tmp = os.path.join(current_dir, "test/tmp/{}.png".format(
             random.getrandbits(32)))
+        time.sleep(GAP_TO_SCREENSHOT)
         driver.save_screenshot(tmp)
         driver.close()
         self.assertIsNone(compare_images(tmp, golden_img, TOLERANCE))
@@ -136,6 +139,7 @@ class TestDemo(unittest.TestCase):
                 (By.CSS_SELECTOR, ".panel:nth-child(2) .component:nth-child(1) .output_image"))
         )
 
+        time.sleep(GAP_TO_SCREENSHOT)
         driver.save_screenshot(tmp)
         self.assertIsNone(compare_images(tmp, golden_img, TOLERANCE))
         os.remove(tmp)
@@ -145,7 +149,7 @@ class TestDemo(unittest.TestCase):
         driver = self.start_test(target=longest_word_thread)
         elem = WebDriverWait(driver, TIMEOUT).until(
             EC.presence_of_element_located((By.CSS_SELECTOR,
-                                            ".panel:nth-child(1) .component:nth-child(1) .input_text"))
+                                            ".panel:nth-child(1) .component:nth-child(1) .input_text textarea"))
         )
         elem.send_keys("This is the most wonderful machine learning "
                        "library.")
@@ -167,6 +171,7 @@ class TestDemo(unittest.TestCase):
             "longest_word", "wonderful"))
         tmp = os.path.join(current_dir, "test/tmp/{}.png".format(
             random.getrandbits(32)))
+        time.sleep(GAP_TO_SCREENSHOT)
         driver.save_screenshot(tmp)
         driver.close()
         self.assertIsNone(compare_images(tmp, golden_img, TOLERANCE))
@@ -189,11 +194,12 @@ class TestDemo(unittest.TestCase):
             total_sleep += 0.2
 
         self.assertEqual(
-            elem.text, "The 2 cats went to the park where they until the night")
+            elem.text, "The 2 cats went to the park where they  until the night")
         golden_img = os.path.join(current_dir, GOLDEN_PATH.format(
             "sentence_builder", "two_cats"))
         tmp = os.path.join(current_dir, "test/tmp/{}.png".format(
             random.getrandbits(32)))
+        time.sleep(GAP_TO_SCREENSHOT)
         driver.save_screenshot(tmp)
         self.assertIsNone(compare_images(tmp, golden_img, TOLERANCE))
         os.remove(tmp)
